==> adwaita-icon-theme-47.0-noarch-1.txz: install/doinst.sh <==
if [ -e /usr/share/icons/Adwaita/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache /usr/share/icons/Adwaita 1> /dev/null 2> /dev/null
  fi
fi

( cd usr/share/icons/Adwaita/cursors ; rm -rf arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf nwse-resize bd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bottom_left_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sw-resize bottom_left_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bottom_right_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf se-resize bottom_right_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bottom_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf s-resize bottom_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf cross )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair cross )
( cd usr/share/icons/Adwaita/cursors ; rm -rf cross_reverse )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair cross_reverse )
( cd usr/share/icons/Adwaita/cursors ; rm -rf diamond_cross )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair diamond_cross )
( cd usr/share/icons/Adwaita/cursors ; rm -rf dnd-move )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default dnd-move )
( cd usr/share/icons/Adwaita/cursors ; rm -rf fd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf nesw-resize fd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf fleur )
( cd usr/share/icons/Adwaita/cursors ; ln -sf move fleur )
( cd usr/share/icons/Adwaita/cursors ; rm -rf hand1 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf grab hand1 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf hand2 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf pointer hand2 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf left_ptr )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default left_ptr )
( cd usr/share/icons/Adwaita/cursors ; rm -rf left_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf w-resize left_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf question_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf help question_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf right_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf e-resize right_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf sb_h_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf ew-resize sb_h_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf sb_v_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf ns-resize sb_v_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf tcross )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair tcross )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_left_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default top_left_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_left_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf nw-resize top_left_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_right_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf ne-resize top_right_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf n-resize top_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf watch )
( cd usr/share/icons/Adwaita/cursors ; ln -sf wait watch )
( cd usr/share/icons/Adwaita/cursors ; rm -rf xterm )
( cd usr/share/icons/Adwaita/cursors ; ln -sf text xterm )

==> adwaita-icon-theme-48.1-noarch-1.txz: install/doinst.sh <==
if [ -e /usr/share/icons/Adwaita/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache /usr/share/icons/Adwaita 1> /dev/null 2> /dev/null
  fi
fi

( cd usr/share/icons/Adwaita/cursors ; rm -rf arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf nwse-resize bd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bottom_left_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf sw-resize bottom_left_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bottom_right_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf se-resize bottom_right_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf bottom_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf s-resize bottom_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf cross )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair cross )
( cd usr/share/icons/Adwaita/cursors ; rm -rf cross_reverse )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair cross_reverse )
( cd usr/share/icons/Adwaita/cursors ; rm -rf diamond_cross )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair diamond_cross )
( cd usr/share/icons/Adwaita/cursors ; rm -rf dnd-move )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default dnd-move )
( cd usr/share/icons/Adwaita/cursors ; rm -rf fd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf nesw-resize fd_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf fleur )
( cd usr/share/icons/Adwaita/cursors ; ln -sf all-resize fleur )
( cd usr/share/icons/Adwaita/cursors ; rm -rf hand1 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf grab hand1 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf hand2 )
( cd usr/share/icons/Adwaita/cursors ; ln -sf pointer hand2 )
( cd usr/share/icons/Adwaita/cursors ; rm -rf left_ptr )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default left_ptr )
( cd usr/share/icons/Adwaita/cursors ; rm -rf left_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf w-resize left_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf move )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default move )
( cd usr/share/icons/Adwaita/cursors ; rm -rf question_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf help question_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf right_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf e-resize right_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf sb_h_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf ew-resize sb_h_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf sb_v_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf ns-resize sb_v_double_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf tcross )
( cd usr/share/icons/Adwaita/cursors ; ln -sf crosshair tcross )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_left_arrow )
( cd usr/share/icons/Adwaita/cursors ; ln -sf default top_left_arrow )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_left_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf nw-resize top_left_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_right_corner )
( cd usr/share/icons/Adwaita/cursors ; ln -sf ne-resize top_right_corner )
( cd usr/share/icons/Adwaita/cursors ; rm -rf top_side )
( cd usr/share/icons/Adwaita/cursors ; ln -sf n-resize top_side )
( cd usr/share/icons/Adwaita/cursors ; rm -rf watch )
( cd usr/share/icons/Adwaita/cursors ; ln -sf wait watch )
( cd usr/share/icons/Adwaita/cursors ; rm -rf xterm )
( cd usr/share/icons/Adwaita/cursors ; ln -sf text xterm )
